==> kdrill_4.0.orig.tar.gz: kdrill-4.0.orig/externs.h <==
/* GLOBAL externs file for kdrill!!
 * Hopefully, the only stuff that is in here, is stuff that should REALLY
 * be globally visible, not just any stuff that happens to be exported
 * by a particular file/module
 */

extern Atom delete_message,wm_message;





extern struct translationstruct *translations[MAXKANJIALLOWED];

extern int lowestkanji,highestkanji,numberofkanji;/* keep track of how many we have */
extern int lowfrequency,highfrequency;		/* for frequency restrictions */

extern char *usefile;

void usage(),quit();
extern void Beep();	/* nice generic routine that respects whether
			 * player wants quiet or not
			 */

extern void MakeFrequency();

extern void SearchCallback(Widget,XtPointer,XtPointer);


/* widget operators.. */
extern int GetWidgetNumberval(Widget);
extern void UnreverseButton(Widget);
extern void SetWidgetNumberval(Widget,int);
extern void SetWidgetHexval(Widget,int);
extern void ReverseButton(Widget);

extern int FindIndex(char *);


extern XFontStruct *largekfont;
extern XFontStruct *smallkfont;
extern XFontStruct *englishfont;

/* other "usefull" generic functions */
extern int xtoi(),getline();
extern void setstatus(char *);


/* callbacks have been moved to their specific .h files */


extern XtAppContext Context;

extern unsigned long black,white;
extern Display	*display;
extern Window	mainwindow,rootwindow;
extern GC	gc,cleargc;

/* buttons 'n' widgets */
extern Widget toplevel,form;
extern Widget options_popup;
extern Widget frequencyForm,frequencyHigh,frequencyLow;
extern Widget buttonform,englishform,kanjiform;
extern Widget kanjimode,englishmode,togglekana;
extern Widget englishWidget[NUMBEROFCHOICES],kanjiWidget[NUMBEROFCHOICES];
extern Widget gradelevelForm,gradeButtons[];
extern Widget usefilebutton,orderbutton;


/* Accelerator functions.. */
extern void UpdateFrequency(Widget,XEvent *,String *,Cardinal *);
extern void DoFind(Widget,XEvent *,String *,Cardinal *);

/* misc resource-level stuffs... */
extern void GetXtString(char *, char *, char *);
extern int GetXtNumber(char *,char *);
extern Boolean GetXtBoolean(char *, char *);

/* These flags indicate current settings of the game */
extern Boolean useUsefile; /*	we Always read in a usefile, but
				this says if we actually use it */
extern Boolean doBell,showinorder;
extern Boolean showEnglish;
extern Boolean switchKanaEnglish;
extern int gradelevelflags;

#ifdef OLDLOG
extern FILE *logfile;
#endif

==> kdrill5.5.1.tar.gz: kdrill5.5.1/externs.h <==
/* GLOBAL externs file for kdrill!!
 * Hopefully, the only stuff that is in here, is stuff that should REALLY
 * be globally visible, not just any stuff that happens to be exported
 * by a particular file/module
 */

extern Atom delete_message,wm_message;





extern TRANSLATION translations[MAXTRANSLATIONSALLOWED];

extern int lowestkanji,highestkanji,numberofkanji;/* keep track of how many we have */
extern int lowfrequency,highfrequency;		/* for frequency restrictions */

extern char *usefile;

extern void usage();
extern void quit(Widget w, XtPointer, XtPointer);
extern void Beep();	/* nice generic routine that respects whether
			 * player wants quiet or not
			 */

extern void MakeFrequency();

extern void SearchCallback(Widget,XtPointer,XtPointer);


/* widget operators.. */
extern int GetWidgetNumberval(Widget);
extern void UnreverseButton(Widget);
extern void SetWidgetNumberval(Widget,int);
extern void SetWidgetHexval(Widget,int);
extern void ReverseButton(Widget);

extern int FindIndex(char *);


extern XFontStruct *largekfont;
extern XFontStruct *smallkfont;
extern XFontStruct *englishfont;

/* other "usefull" generic functions */
extern int xtoi(char *), getline(FILE *, unsigned char *);
extern void setstatus(char *);


/* callbacks have been moved to their specific .h files */


extern XtAppContext Context;

extern unsigned long black,white;
extern Display	*display;
extern Window	mainwindow,rootwindow;
extern GC	gc,cleargc;

/* buttons 'n' widgets */
extern Widget toplevel,form;
extern Widget options_popup;
extern Widget frequencyForm,frequencyHigh,frequencyLow;
extern Widget buttonform,englishform,kanjiform;

extern Widget choicesWidgets[NUMBEROFCHOICES],questionWidget;

extern Widget gradelevelForm,gradeButtons[];
extern Widget usefilebutton,orderbutton;


/* Accelerator functions.. */
extern void UpdateFrequency(Widget,XEvent *,String *,Cardinal *);
extern void DoFind(Widget,XEvent *,String *,Cardinal *);

/* misc resource-level stuffs... */
extern void GetXtString(char *, char *, char *);
extern int GetXtNumber(char *,char *);
extern Boolean GetXtBoolean(char *, char *);

/* These flags indicate current settings of the game */
extern Boolean useUsefile; /*	we Always read in a usefile, but
				this says if we actually use it */
extern Boolean doBell,showinorder;
extern Boolean showEnglish;
extern Boolean switchKanaEnglish;
extern int gradelevelflags;

#ifdef OLDLOG
extern FILE *logfile;
#endif
